aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/debug_test.py2
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/dnn_linear_combined_test.py4
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/dnn_test.py2
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/head.py8
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/linear_test.py2
-rw-r--r--tensorflow/contrib/learn/python/learn/estimators/model_fn.py16
-rw-r--r--tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils.py4
-rw-r--r--tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils_test.py20
-rw-r--r--tensorflow/core/util/example_proto_fast_parsing_test.cc2
9 files changed, 31 insertions, 29 deletions
diff --git a/tensorflow/contrib/learn/python/learn/estimators/debug_test.py b/tensorflow/contrib/learn/python/learn/estimators/debug_test.py
index 6b125534a4..c4e5686bc9 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/debug_test.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/debug_test.py
@@ -564,7 +564,7 @@ class DebugClassifierTest(test.TestCase):
self.assertEqual(list(predictions1), list(predictions2))
def testExport(self):
- """Tests export model for servo."""
+ """Tests export model for TensorFlow Serving."""
def input_fn():
return {
diff --git a/tensorflow/contrib/learn/python/learn/estimators/dnn_linear_combined_test.py b/tensorflow/contrib/learn/python/learn/estimators/dnn_linear_combined_test.py
index 4e65c180d8..0177ccbbcb 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/dnn_linear_combined_test.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/dnn_linear_combined_test.py
@@ -896,7 +896,7 @@ class DNNLinearCombinedClassifierTest(test.TestCase):
classifier.get_variable_value(name)
def testExport(self):
- """Tests export model for servo."""
+ """Tests export model for TensorFlow Serving."""
def input_fn():
return {
@@ -1535,7 +1535,7 @@ class DNNLinearCombinedRegressorTest(test.TestCase):
})
def testExport(self):
- """Tests export model for servo."""
+ """Tests export model for TensorFlow Serving."""
labels = [1., 0., 0.2]
def _input_fn(num_epochs=None):
diff --git a/tensorflow/contrib/learn/python/learn/estimators/dnn_test.py b/tensorflow/contrib/learn/python/learn/estimators/dnn_test.py
index 12f9bba531..4ee3040f06 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/dnn_test.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/dnn_test.py
@@ -965,7 +965,7 @@ class DNNClassifierTest(test.TestCase):
self.assertIn('loss', scores)
def testExport(self):
- """Tests export model for servo."""
+ """Tests export model for TensorFlow Serving."""
def input_fn():
return {
diff --git a/tensorflow/contrib/learn/python/learn/estimators/head.py b/tensorflow/contrib/learn/python/learn/estimators/head.py
index bc0e6fc009..5c7358089f 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/head.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/head.py
@@ -2047,10 +2047,10 @@ def _classification_output_alternatives(head_name, problem_type,
label_keys=None):
"""Creates a func to generate output alternatives for classification.
- Servo expects classes to be a string tensor, and have the same dimensions
- as the probabilities tensor. It should contain the labels of the corresponding
- entries in probabilities. This function creates a new classes tensor that
- satisfies these conditions and can be exported.
+ TensorFlow Serving expects classes to be a string tensor, and have the same
+ dimensions as the probabilities tensor. It should contain the labels of the
+ corresponding entries in probabilities. This function creates a new classes
+ tensor that satisfies these conditions and can be exported.
Args:
head_name: Name of the head.
diff --git a/tensorflow/contrib/learn/python/learn/estimators/linear_test.py b/tensorflow/contrib/learn/python/learn/estimators/linear_test.py
index d3bb0fda57..99638ca345 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/linear_test.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/linear_test.py
@@ -620,7 +620,7 @@ class LinearClassifierTest(test.TestCase):
self.assertLess(loss_weighted, loss_unweighted)
def testExport(self):
- """Tests that export model for servo works."""
+ """Tests that export model for TensorFlow Serving works."""
def input_fn():
return {
diff --git a/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils.py b/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils.py
index ea5cb264ec..94404521fa 100644
--- a/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils.py
+++ b/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils.py
@@ -136,7 +136,7 @@ def _get_classification_scores(output_tensors):
def _get_classification_classes(output_tensors):
classes = output_tensors.get(prediction_key.PredictionKey.CLASSES)
if classes is not None and classes.dtype != dtypes.string:
- # Servo classification can only serve string classes.
+ # TensorFlow Serving classification can only serve string classes.
return None
return classes
@@ -465,7 +465,7 @@ def make_export_strategy(serving_input_fn,
garbage_collect_exports(export_dir_base, exports_to_keep)
return export_result
- return export_strategy.ExportStrategy('Servo', export_fn)
+ return export_strategy.ExportStrategy('TFServing', export_fn)
def make_parsing_export_strategy(feature_columns,
diff --git a/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils_test.py b/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils_test.py
index 14bf1136e8..d3748db7d2 100644
--- a/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils_test.py
+++ b/tensorflow/contrib/learn/python/learn/utils/saved_model_export_utils_test.py
@@ -267,8 +267,8 @@ class SavedModelExportUtilsTest(test.TestCase):
def test_build_standardized_signature_def_classification5(self):
"""Tests multiple output tensors that include integer classes and scores.
- Integer classes are dropped out, because Servo classification can only serve
- string classes. So, only scores are present in the signature.
+ Integer classes are dropped out, because TensorFlow Serving classification
+ can only serve string classes. So, only scores are present in the signature.
"""
input_tensors = {
"input-1":
@@ -311,8 +311,8 @@ class SavedModelExportUtilsTest(test.TestCase):
def test_build_standardized_signature_def_classification6(self):
"""Tests multiple output tensors that with integer classes and no scores.
- Servo classification cannot serve integer classes, but no scores are
- available. So, we fall back to predict signature.
+ TensorFlow Serving classification cannot serve integer classes, but no
+ scores are available. So, we fall back to predict signature.
"""
input_tensors = {
"input-1":
@@ -813,11 +813,11 @@ class SavedModelExportUtilsTest(test.TestCase):
return post_export_path
base_export_strategy = export_strategy_lib.ExportStrategy(
- "Servo", _base_export_fn)
+ "TFServing", _base_export_fn)
final_export_strategy = saved_model_export_utils.extend_export_strategy(
- base_export_strategy, _post_export_fn, "Servo2")
- self.assertEqual(final_export_strategy.name, "Servo2")
+ base_export_strategy, _post_export_fn, "TFServing2")
+ self.assertEqual(final_export_strategy.name, "TFServing2")
test_estimator = TestEstimator()
tmpdir = tempfile.mkdtemp()
@@ -843,11 +843,11 @@ class SavedModelExportUtilsTest(test.TestCase):
return post_export_path
base_export_strategy = export_strategy_lib.ExportStrategy(
- "Servo", _base_export_fn)
+ "TFServing", _base_export_fn)
final_export_strategy = saved_model_export_utils.extend_export_strategy(
base_export_strategy, _post_export_fn)
- self.assertEqual(final_export_strategy.name, "Servo")
+ self.assertEqual(final_export_strategy.name, "TFServing")
test_estimator = TestEstimator()
tmpdir = tempfile.mkdtemp()
@@ -870,7 +870,7 @@ class SavedModelExportUtilsTest(test.TestCase):
return tempfile.mkdtemp()
base_export_strategy = export_strategy_lib.ExportStrategy(
- "Servo", _base_export_fn)
+ "TFServing", _base_export_fn)
final_export_strategy = saved_model_export_utils.extend_export_strategy(
base_export_strategy, _post_export_fn)
diff --git a/tensorflow/core/util/example_proto_fast_parsing_test.cc b/tensorflow/core/util/example_proto_fast_parsing_test.cc
index 9b6a8e1251..4e55a38dc5 100644
--- a/tensorflow/core/util/example_proto_fast_parsing_test.cc
+++ b/tensorflow/core/util/example_proto_fast_parsing_test.cc
@@ -150,7 +150,7 @@ TEST(FastParse, DenseInt64WithContext) {
EXPECT_TRUE(deserialized.ParseFromString(serialized));
EXPECT_EQ(deserialized.DebugString(), context.DebugString());
// Whoa! Last EQ is very surprising, but standard deserialization is what it
- // is and Servo team requested to replicate this 'feature'.
+ // is and TensorFlow Serving team requested to replicate this 'feature'.
// In future we should return error.
}
TestCorrectness(serialized);
diff --git a/tensorflow/contrib/learn/python/learn/estimators/model_fn.py b/tensorflow/contrib/learn/python/learn/estimators/model_fn.py
index 44e6c7c52d..fb58d2ad5b 100644
--- a/tensorflow/contrib/learn/python/learn/estimators/model_fn.py
+++ b/tensorflow/contrib/learn/python/learn/estimators/model_fn.py
@@ -200,10 +200,10 @@ class ModelFnOps(
default_serving_output_alternative_key: Required for multiple heads. If
you have multiple entries in `output_alternatives` dict (comparable to
multiple heads), `EstimatorSpec` requires a default head that will be
- used if a Servo request does not explicitly mention which head to infer
- on. Pass the key of the output alternative here that you want to
- designate as default. A separate ExportOutpout for this default head
- wil be added to the export_outputs dict with the special key
+ used if a TensorFlow Serving request does not explicitly mention which
+ head to infer on. Pass the key of the output alternative here that you
+ want to designate as default. A separate ExportOutpout for this default
+ head will be added to the export_outputs dict with the special key
signature_constants.DEFAULT_SERVING_SIGNATURE_DEF_KEY, unless there is
already an enry in output_alternatives with this special key.
@@ -223,12 +223,14 @@ class ModelFnOps(
classes = output_tensors.get(prediction_key.PredictionKey.CLASSES)
if classes is None:
logging.warning(
- 'classes is None, Servo inference will not have class ids.')
+ 'classes is None, TensorFlow Serving inference will not have '
+ 'class ids.')
return None
elif classes.dtype != dtypes.string:
# Servo classification can only serve string classes
logging.warning(
- 'classes is not string, Servo inference will not have class ids.')
+ 'classes is not string, TensorFlow Serving inference will not have '
+ 'class ids.')
return None
return classes
@@ -223,12 +223,14 @@ class ModelFnOps(
return None
elif classes.dtype != dtypes.string:
- # Servo classification can only serve string classes
+ # TensorFlow Serving classification can only serve string classes
logging.warning(